summaryrefslogtreecommitdiff
path: root/src/include/lib.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/lib.h')
-rw-r--r--src/include/lib.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/include/lib.h b/src/include/lib.h
index ad416e0a..08643220 100644
--- a/src/include/lib.h
+++ b/src/include/lib.h
@@ -1,5 +1,5 @@
// -*- C++ -*-
-/* Copyright (C) 1989-2000 Free Software Foundation, Inc.
+/* Copyright (C) 1989-2000, 2001 Free Software Foundation, Inc.
Written by James Clark (jjc@jclark.com)
This file is part of groff.
@@ -26,9 +26,11 @@ extern "C" {
const char *if_to_a(int, int);
}
-/* stdio.h on IRIX and OSF/1 include getopt.h */
+/* stdio.h on IRIX, OSF/1, and UWIN includes getopt.h */
-#if !(defined(__sgi) || (defined(__osf__) && defined(__alpha)))
+#if !(defined(__sgi) \
+ || (defined(__osf__) && defined(__alpha)) \
+ || defined(_UWIN))
#include <groff-getopt.h>
#endif